# Snaketool-utils

[![](https://img.shields.io/static/v1?label=Licence&message=MIT&color=black)](https://opensource.org/license/mit/)
[![](https://img.shields.io/static/v1?label=Install%20with&message=PIP&color=success)](https://pypi.org/project/snaketool-utils/)
![GitHub last commit (branch)](https://img.shields.io/github/last-commit/beardymcjohnface/Snaketool-utils/main)
[![Unit tests](https://github.com/beardymcjohnface/Snaketool-utils/actions/workflows/py-app.yml/badge.svg)](https://github.com/beardymcjohnface/Snaketool-utils/actions/workflows/py-app.yml)
[![Documentation Status](https://readthedocs.org/projects/snaketool-utils/badge/?version=latest)](https://snaketool-utils.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/beardymcjohnface/Snaketool-utils/branch/main/graph/badge.svg?token=oFnN9G4bEZ)](https://codecov.io/gh/beardymcjohnface/Snaketool-utils)

---

Utility functions for the [Snaketool](https://github.com/beardymcjohnface/Snaketool) CLI for Snakemake.
You can read the API docs hosted on [ReadTheDocs](https://snaketool-utils.readthedocs.io/en/latest/).

## Install

```shell
pip install snaketool-utils
```

__Dev install__

```shell
git clone https://github.com/beardymcjohnface/Snaketool-utils.git
cd Snaketool-utils
pip install -e .
```